@@ -1,9 +1,10 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.7
 
 ## Printing troubleshooter
 
-## Copyright (C) 2008 Red Hat, Inc.
-## Copyright (C) 2008 Tim Waugh <twaugh@redhat.com>
+## Copyright (C) 2008, 2009, 2010 Red Hat, Inc.
+## Authors:
+##  Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -17,16 +18,16 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import cups
 import cupshelpers
+import installpackage
 import os
 import subprocess
+from timedops import TimedOperation, TimedSubprocess
 from base import *
 
-install_cmd = "/usr/bin/true"
-
 class CheckPPDSanity(Question):
     def __init__ (self, troubleshooter):
         Question.__init__ (self, troubleshooter, "Check PPD sanity")
@@ -58,12 +59,15 @@ class CheckPPDSanity(Question):
         if not answers['cups_queue_listed']:
             return False
 
+        parent = self.troubleshooter.get_window ()
         name = answers['cups_queue']
         tmpf = None
         try:
             cups.setServer ('')
-            c = cups.Connection ()
-            tmpf = c.getPPD (name)
+            self.op = TimedOperation (cups.Connection, parent=parent)
+            c = self.op.run ()
+            self.op = TimedOperation (c.getPPD, args=(name,), parent=parent)
+            tmpf = self.op.run ()
         except RuntimeError:
             return False
         except cups.IPPError:
@@ -93,20 +97,22 @@ class CheckPPDSanity(Question):
             title = _("Invalid PPD File")
             self.answers['cups_printer_ppd_valid'] = False
             try:
-                p = subprocess.Popen (['cupstestppd', '-rvv', tmpf],
-                                      stdin=file("/dev/null"),
-                                      stdout=subprocess.PIPE,
-                                      stderr=subprocess.PIPE)
-                (stdout, stderr) = p.communicate ()
-                self.answers['cupstestppd_output'] = (stdout, stderr)
-                text = _("The PPD file for printer `%s' does not conform "
+                self.op = TimedSubprocess (parent=parent,
+                                           args=['cupstestppd', '-rvv', tmpf],
+                                           close_fds=True,
+                                           stdin=file("/dev/null"),
+                                           stdout=subprocess.PIPE,
+                                           stderr=subprocess.PIPE)
+                result = self.op.run ()
+                self.answers['cupstestppd_output'] = result
+                text = _("The PPD file for printer '%s' does not conform "
                          "to the specification.  "
                          "Possible reason follows:") % name
-                text += '\n' + stdout
+                text += '\n' + reduce (lambda x, y: x + '\n' + y, result[0])
             except OSError:
                 # Perhaps cupstestppd is not in the path.
                 text = _("There is a problem with the PPD file for "
-                         "printer `%s'.") % name
+                         "printer '%s'.") % name
 
         if tmpf:
             os.unlink (tmpf)
@@ -116,14 +122,20 @@ class CheckPPDSanity(Question):
             self.answers['missing_pkgs_and_exes'] = (pkgs, exes)
             if len (pkgs) > 0 or len (exes) > 0:
                 title = _("Missing Printer Driver")
-                if len (pkgs) > 0 and os.access (install_cmd, os.X_OK):
+                if len (pkgs) > 0:
+                    try:
+                        self.packagekit = installpackage.PackageKit ()
+                    except:
+                        pkgs = []
+
+                if len (pkgs) > 0:
                     self.package = pkgs[0]
-                    text = _("Printer `%s' requires the %s package but it "
+                    text = _("Printer '%s' requires the %s package but it "
                              "is not currently installed.") % (name,
                                                                self.package)
                     self.install_button.show ()
                 else:
-                    text = _("Printer `%s' requires the `%s' program but it "
+                    text = _("Printer '%s' requires the '%s' program but it "
                              "is not currently installed.") % (name,
                                                                (exes + pkgs)[0])
 
@@ -143,8 +155,14 @@ class CheckPPDSanity(Question):
     def collect_answer (self):
         return self.answers
 
+    def cancel_operation (self):
+        self.op.cancel ()
+
     def install_clicked (self, button):
         pkgs = self.answers.get('packages_installed', [])
         pkgs.append (self.package)
         self.answers['packages_installed'] = pkgs
-        subprocess.Popen ([install_cmd, self.package])
+        try:
+            self.packagekit.InstallPackageName (0, 0, self.package)
+        except:
+            pass
