@@ -1,9 +1,9 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 
 ## Printing troubleshooter
 
-## Copyright (C) 2008 Red Hat, Inc.
-## Copyright (C) 2008 Tim Waugh <twaugh@redhat.com>
+## Copyright (C) 2008, 2009 Red Hat, Inc.
+## Copyright (C) 2008, 2009 Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -17,9 +17,10 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import cups
+from timedops import TimedOperation
 from base import *
 class NetworkCUPSPrinterShared(Question):
     def __init__ (self, troubleshooter):
@@ -36,15 +37,22 @@ class NetworkCUPSPrinterShared(Question):
             answers['remote_cups_queue_listed'] == False):
             return False
 
+        parent = self.troubleshooter.get_window ()
         if not answers.has_key ('remote_cups_queue_attributes'):
             if not (answers.has_key ('remote_server_try_connect') and
                     answers.has_key ('remote_cups_queue')):
                 return False
 
             try:
-                cups.setServer (answers['remote_server_try_connect'])
-                c = cups.Connection ()
-                attr = c.getPrinterAttributes (answers['remote_cups_queue'])
+                host = answers['remote_server_try_connect']
+                self.op = TimedOperation (cups.Connection,
+                                          kwargs={"host": host},
+                                          parent=parent)
+                c = self.op.run ()
+                self.op = TimedOperation (c.getPrinterAttributes,
+                                          args=(answers['remote_cups_queue'],),
+                                          parent=parent)
+                attr = self.op.run ()
             except RuntimeError:
                 return False
             except cups.IPPError:
@@ -66,3 +74,6 @@ class NetworkCUPSPrinterShared(Question):
 
     def collect_answer (self):
         return self.answers
+
+    def cancel_operation (self):
+        self.op.cancel ()
