@@ -1,9 +1,9 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.7
 
 ## Printing troubleshooter
 
-## Copyright (C) 2008 Red Hat, Inc.
-## Copyright (C) 2008 Tim Waugh <twaugh@redhat.com>
+## Copyright (C) 2008, 2009 Red Hat, Inc.
+## Copyright (C) 2008, 2009 Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import cups
 from base import *
@@ -53,14 +53,14 @@ class QueueNotEnabled(Question):
             reason = queue['printer-state-message']
 
         if reason:
-            reason = _("The reason given is: `%s'.") % reason
+            reason = _("The reason given is: '%s'.") % reason
         else:
             reason = _("This may be due to the printer being disconnected or "
                        "switched off.")
 
         text = ('<span weight="bold" size="larger">' +
                 _("Queue Not Enabled") + '</span>\n\n' +
-                _("The queue `%s' is not enabled.") %
+                _("The queue '%s' is not enabled.") %
                 answers['cups_queue'])
 
         if reason:
@@ -68,10 +68,10 @@ class QueueNotEnabled(Question):
 
         if not answers['cups_printer_remote']:
             text += '\n\n'
-            text += _("To enable it, select the `Enabled' checkbox in the "
-                      "`Policies' tab for the printer in the printer "
+            text += _("To enable it, select the 'Enabled' checkbox in the "
+                      "'Policies' tab for the printer in the printer "
                       "administration tool.")
-            text += ' ' + TEXT_start_print_admin_tool
+            text += ' ' + _(TEXT_start_print_admin_tool)
 
         self.label.set_markup (text)
         return True
